( cd opt/kde/share/doc/HTML/en_GB/klatin ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/klatin ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kmplot ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kstars ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kturtle ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/opengl ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kbabel ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/umbrello ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/cervisia ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kompare ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-left.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-middle.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-right.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-left.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-left.png top-left.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-middle.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-right-konqueror.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/en_GB/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/knode ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kleopatra ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/knotes ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kalarm ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kmail ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kspell ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kate ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/konqueror ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kfind ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/ksplashml ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kxkb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kwrite ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/klipper ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kicker ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kpager ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/konsole ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdm ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kdesu ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
( cd opt/kde/share/doc/HTML/en_GB/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/en_GB/kioslave ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
